/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.ui.wizards.pages;

import org.safe.ide.ui.messages.WorkspaceUIMessages;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.sphinx.emf.workspace.ui.wizards.pages.NewModelFileCreationPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Text;
import org.safe.ide.ui.internal.messages.Messages;
import org.safe.ide.metamodel.SAFEReleaseDescriptor;
import org.safe.ide.preferences.ISAFEWorkspacePreferences;

public class NewSAFEFileCreationPage extends NewModelFileCreationPage<SAFEReleaseDescriptor>{
	
	private Button createInitialSAFEPackageButton;
	private Text initialSAFEPackageName;
	/**
	 * @param pageId
	 * @param selection
	 * @param elements
	 */
	public NewSAFEFileCreationPage(String pageId, IStructuredSelection selection) {
		super(pageId, selection, ISAFEWorkspacePreferences.SAFE_RELEASE);
		setTitle(WorkspaceUIMessages.page_NewSAFEFileCreation_title);
		setDescription(WorkspaceUIMessages.page_NewSAFEFileCreation_description);
	}
	
	/*
	 * @see
	 * org.eclipse.sphinx.emf.workspace.ui.wizards.pages.NewModelFileCreationPage#createAdditionalControls(org.eclipse
	 * .swt.widgets.Composite)
	 */
	@Override
	protected void createAdditionalControls(Composite parent) {
		createInitialSAFEPackageGroup(parent);

		Dialog.applyDialogFont(getControl());
	}
	
	protected void createInitialSAFEPackageGroup(Composite parent) {
		Group fGroup = new Group(parent, SWT.NONE);
		fGroup.setText(WorkspaceUIMessages.label_SAFEPackageCreation);
		fGroup.setLayout(new GridLayout(2, false));
		fGroup.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));

		createInitialSAFEPackageButton = new Button(fGroup, SWT.CHECK);
		GridData gd = new GridData();
		gd.horizontalSpan = 2;
		createInitialSAFEPackageButton.setLayoutData(gd);
		createInitialSAFEPackageButton.setText(WorkspaceUIMessages.label_WithSAFEPackage);
		createInitialSAFEPackageButton.setSelection(true);

		initialSAFEPackageName = new Text(fGroup, SWT.SINGLE | SWT.BORDER);
		initialSAFEPackageName.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		initialSAFEPackageName.setText(WorkspaceUIMessages.text_defaultSAFEPackageName);
		createInitialSAFEPackageButton.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				initialSAFEPackageName.setEnabled(createInitialSAFEPackageButton.getSelection());
			}
		});
	}
	
	public String getSAFEPackageName() {
		if (createInitialSAFEPackageButton.getSelection() && !(initialSAFEPackageName.getText().length() == 0)) {
			return initialSAFEPackageName.getText();
		}
		return null;
	}
	
	/*
	 * @see
	 * org.eclipse.sphinx.emf.workspace.ui.wizards.pages.NewModelFileCreationPage#getRequiredProjectNatureErrorMessage()
	 */
	@Override
	protected String getRequiredProjectNatureErrorMessage() {
		return Messages.error_requiredProjectNature;
	}
}
