/**
 * <copyright>
 * 
 * Copyright (c) 2013 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.safe.ide.metamodel;

import org.eclipse.core.runtime.Assert;
import org.eclipse.sphinx.emf.metamodel.MetaModelVersionData;

public class SAFEMetaModelVersionData extends MetaModelVersionData implements
	Comparable<SAFEMetaModelVersionData> {
    private int major;
    private int minor;
    private int revision;

    public SAFEMetaModelVersionData(String nsPostfix,
	    String ePackageNsURIPostfixPattern, String name, int major,
	    int minor, int revision, int ordinal) {
    	super(nsPostfix, ePackageNsURIPostfixPattern, name, SAFEReleaseDescriptor.INSTANCE);
	this.major = major;
	this.minor = minor;
	this.revision = revision;
    }

    public int getMajor() {
	return major;
    }

    public int getMinor() {
	return minor;
    }

    public int getRevision() {
	return revision;
    }

    public int compareTo(SAFEMetaModelVersionData other) {
	int result;

	result = new Integer(major).compareTo(other.major);
	if (result != 0) {
	    return result;
	}

	result = new Integer(minor).compareTo(other.minor);
	if (result != 0) {
	    return result;
	}

	result = new Integer(revision).compareTo(other.revision);

	return result;
    }

    private static int calculateOrdinal(int major, int minor, int revision) {
	assertRange(major);
	assertRange(minor);
	assertRange(revision);

	int ordinal = 0;
	ordinal = ordinal * 100 + major;
	ordinal = ordinal * 100 + minor;
	ordinal = ordinal * 100 + revision;
	return ordinal;
    }

    private static void assertRange(int i) {
	Assert.isTrue(i >= 0 && i < 100);
    }
}
