/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.errormodel.errorbehavior;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.commonstructure.toplevel.Identifiable;

import safe10.classmodel.errormodel.errormodeltype.ErrorModelType;

import safe10.classmodel.errormodel.malfunction.MalfunctionPrototype;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Abstract Error Behavior</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class contains information about the error behavior independent of concrete behavior descriptions.
 * 
 * The AbstractErrorBehavior contains internalFaults, representing faults that are either propagated to externalFailures of the ErrorModelType or masked, according to the definition of its fault propagation.
 * 
 * A processFault represents a flaw introduced during design, and may lead to any of the failures represented by the ErrorModelType. A processFault therefore has a direct propagation to all externalFailures and cannot be masked. 
 * 
 * Each error behavior description relates the occurrences of internal faults and incoming external faults to external failures. The faults and failures that the error behavior propagates to and from the target element are declared through the malfunction prototypes of the error model.
 * 
 * Semantics: 
 * An error behavior describes the error propagation logic of its containing ErrorModelType.
 * The ErrorBehavior description represents the error propagation from internal faults or external faults to external failures. Faults are identified by the internalFault externalFault associations. The propagated external failures are identified by the externalFailure association. 
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.errormodel.errorbehavior.AbstractErrorBehavior#getErrorModel <em>Error Model</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errorbehavior.AbstractErrorBehavior#getProcessFault <em>Process Fault</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errorbehavior.AbstractErrorBehavior#getInternalFault <em>Internal Fault</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.errormodel.errorbehavior.ErrorbehaviorPackage#getAbstractErrorBehavior()
 * @model abstract="true"
 *        annotation="MetaData guid='{32005160-AD0F-433f-AB77-8A26FD8947B9}' id='2016434680' EA\040name='AbstractErrorBehavior'"
 *        annotation="TaggedValues xml.name='ABSTRACT-ERROR-BEHAVIOR' xml.namePlural='ABSTRACT-ERROR-BEHAVIORS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface AbstractErrorBehavior extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Error Model</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Error Model</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Error Model</em>' reference.
   * @see #setErrorModel(ErrorModelType)
   * @see safe10.classmodel.errormodel.errorbehavior.ErrorbehaviorPackage#getAbstractErrorBehavior_ErrorModel()
   * @model required="true"
   *        annotation="MetaData guid='{5B422AC0-A8AB-47c3-A66D-5077A60E41A1}' id='-560186768' EA\040name=''"
   *        annotation="TaggedValues xml.name='ERROR-MODEL-REF' xml.namePlural='ERROR-MODEL-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  ErrorModelType getErrorModel();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.errorbehavior.AbstractErrorBehavior#getErrorModel <em>Error Model</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Error Model</em>' reference.
   * @see #getErrorModel()
   * @generated
   */
  void setErrorModel(ErrorModelType value);

  /**
   * Returns the value of the '<em><b>Process Fault</b></em>' containment reference list.
   * The list contents are of type {@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * processFaults that may affect the ErrorBehavior of the architectural element associated via the ErrorModelType
   * <!-- end-model-doc -->
   * @return the value of the '<em>Process Fault</em>' containment reference list.
   * @see safe10.classmodel.errormodel.errorbehavior.ErrorbehaviorPackage#getAbstractErrorBehavior_ProcessFault()
   * @model containment="true"
   *        annotation="MetaData guid='{2F1DF07F-76B2-4789-8ADB-7EB860C542A3}' id='-2018818036' EA\040name=''"
   *        annotation="TaggedValues xml.name='PROCESS-FAULT' xml.namePlural='PROCESS-FAULTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='false' xml.roleWrapperElement='true' xml.typeElement='true' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<MalfunctionPrototype> getProcessFault();

  /**
   * Returns the value of the '<em><b>Internal Fault</b></em>' containment reference list.
   * The list contents are of type {@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * internalFaults that may affect the ErrorBehavior of the architectural element associated via the ErrorModelType
   * <!-- end-model-doc -->
   * @return the value of the '<em>Internal Fault</em>' containment reference list.
   * @see safe10.classmodel.errormodel.errorbehavior.ErrorbehaviorPackage#getAbstractErrorBehavior_InternalFault()
   * @model containment="true"
   *        annotation="MetaData guid='{B71301A6-7A91-47e6-B560-C276C606E89B}' id='1025457710' EA\040name=''"
   *        annotation="TaggedValues xml.name='INTERNAL-FAULT' xml.namePlural='INTERNAL-FAULTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='false' xml.roleWrapperElement='true' xml.typeElement='true' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<MalfunctionPrototype> getInternalFault();

} // AbstractErrorBehavior
