/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.errormodel.errormodeltype;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.errormodel.malfunction.MalfunctionPrototype;

import safe10.classmodel.requirements.TraceableSpecification;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Error Model Type</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * ErrorModelType and ErrorModelPrototype support the hierarchical composition of error models based on the type-prototype pattern also adopted for the nominal architecture composition. The purpose of the error models is to represent information relating to the anomalies of a nominal model element. 
 * 
 * Independent of the different subtypes of ErrorModelType, this class describes the external faults  affecting the element, external failures caused by the element and fault propagations within the nominal element. 
 * 
 * ErrorModelType inherits the abstract metaclass TraceableSpecification, allowing the ErrorModelType to be referenced from its design context in a similar way as requirements, test cases and other specifications. 
 * 
 * Constraints:
 * For An ErrorModelType without part, a respective error behavior shall be defined in the safety model.
 * 
 * Semantics:
 * The ErrorModelType represents a specification of the faults and fault propagations of its target element.
 * 
 * Both types and prototypes may be targets, and the following cases are relevant:
 * 
 * - One nominal type:
 * 
 * The ErrorModelType represents the identified nominal type wherever this nominal type is instantiated.
 * 
 * - Several nominal types:
 * 
 * The ErrorModelType represents the identified nominal types individually, i.e. the same error model applies to all nominal types and is reused.
 * 
 * - One nominal prototype:
 * 
 * The ErrorModelType represents the identified nominal prototype whenever its context, i.e. its top-level composition is instantiated.
 * 
 * - Several nominal prototypes with instanceref:
 * 
 * The ErrorModelType represents the identified set of nominal prototypes (together) whenever their context, i.e. their top-level composition, is instantiated.
 * 
 * The fault propagation of an errorModelType is defined by its contained parts, the ErrorModelPrototypes and their connections. In case an error behavior is defined for this error model type, the fault propagation information, the error behavior and the parts of the error model shall be consistent.
 * 
 * FaultFailurePropagationLinks define valid propagation paths in the ErrorModelType. In case the contained external faults and external failures reference nominal ports, the connectivity of the nominal model may serve as a pattern for connecting malfunction prototypes in the ErrorModelType.
 * 
 * Extension:
 * (see ADLTraceableSpecfication)
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getGenericDescription <em>Generic Description</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getIsOfType <em>Is Of Type</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getFaultFailureConnector <em>Fault Failure Connector</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getPart <em>Part</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getExternalFault <em>External Fault</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getExternalFailure <em>External Failure</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getErrorModelType()
 * @model annotation="MetaData guid='{EB5607C1-5B47-43dd-81EC-C0D12D27F069}' id='407964011' EA\040name='ErrorModelType'"
 *        annotation="Stereotype Stereotype='atpType'"
 *        annotation="TaggedValues xml.name='ERROR-MODEL-TYPE' xml.namePlural='ERROR-MODEL-TYPES' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface ErrorModelType extends TraceableSpecification
{
  /**
   * Returns the value of the '<em><b>Generic Description</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Generic Description</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Generic Description</em>' attribute.
   * @see #isSetGenericDescription()
   * @see #unsetGenericDescription()
   * @see #setGenericDescription(String)
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getErrorModelType_GenericDescription()
   * @model default="" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.String" required="true"
   *        annotation="MetaData guid='{580E8E89-4F2F-4ee6-B3CF-BAE775F07605}' id='-1737176624' EA\040name='genericDescription'"
   *        annotation="TaggedValues xml.name='GENERIC-DESCRIPTION' xml.namePlural='GENERIC-DESCRIPTIONS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  String getGenericDescription();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getGenericDescription <em>Generic Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Generic Description</em>' attribute.
   * @see #isSetGenericDescription()
   * @see #GenericDescription()
   * @see #getGenericDescription()
   * @generated
   */
  void setGenericDescription(String value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getGenericDescription <em>Generic Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetGenericDescription()
   * @see #getGenericDescription()
   * @see #setGenericDescription(String)
   * @generated
   */
  void unsetGenericDescription();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getGenericDescription <em>Generic Description</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Generic Description</em>' attribute is set.
   * @see #GenericDescription()
   * @see #getGenericDescription()
   * @see #setGenericDescription(String)
   * @generated
   */
  boolean isSetGenericDescription();

  /**
   * Returns the value of the '<em><b>Is Of Type</b></em>' reference.
   * It is bidirectional and its opposite is '{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelPrototype#getType <em>Type</em>}'.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Is Of Type</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Is Of Type</em>' reference.
   * @see #setIsOfType(ErrorModelPrototype)
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getErrorModelType_IsOfType()
   * @see safe10.classmodel.errormodel.errormodeltype.ErrorModelPrototype#getType
   * @model opposite="type"
   *        annotation="TaggedValues xml.name='IS-OF-TYPE-REF' xml.namePlural='IS-OF-TYPE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  ErrorModelPrototype getIsOfType();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.errormodeltype.ErrorModelType#getIsOfType <em>Is Of Type</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Is Of Type</em>' reference.
   * @see #getIsOfType()
   * @generated
   */
  void setIsOfType(ErrorModelPrototype value);

  /**
   * Returns the value of the '<em><b>Fault Failure Connector</b></em>' containment reference list.
   * The list contents are of type {@link safe10.classmodel.errormodel.errormodeltype.FaultFailurePropagationLink}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The contained links for internal propagation of faults/failures between the subordinate error models.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Fault Failure Connector</em>' containment reference list.
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getErrorModelType_FaultFailureConnector()
   * @model containment="true"
   *        annotation="MetaData guid='{5834E9A2-9389-4e6d-AB4D-4312B81EF036}' id='-1893015005' EA\040name=''"
   *        annotation="TaggedValues xml.name='FAULT-FAILURE-CONNECTOR' xml.namePlural='FAULT-FAILURE-CONNECTORS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='false' xml.roleWrapperElement='true' xml.typeElement='true' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<FaultFailurePropagationLink> getFaultFailureConnector();

  /**
   * Returns the value of the '<em><b>Part</b></em>' containment reference list.
   * The list contents are of type {@link safe10.classmodel.errormodel.errormodeltype.ErrorModelPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The contained error models forming a hierarchy.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Part</em>' containment reference list.
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getErrorModelType_Part()
   * @model containment="true"
   *        annotation="MetaData guid='{CE8E4F6F-0FC5-49fe-BAF8-B2BF63733CE0}' id='1898538219' EA\040name=''"
   *        annotation="TaggedValues xml.name='PART' xml.namePlural='PARTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='false' xml.roleWrapperElement='true' xml.typeElement='true' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<ErrorModelPrototype> getPart();

  /**
   * Returns the value of the '<em><b>External Fault</b></em>' containment reference list.
   * The list contents are of type {@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The external faults affecting the proper execution of the architectural element associated with the error model type
   * <!-- end-model-doc -->
   * @return the value of the '<em>External Fault</em>' containment reference list.
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getErrorModelType_ExternalFault()
   * @model containment="true"
   *        annotation="MetaData guid='{65306F93-1BFF-4d79-951A-F84B7E747A46}' id='-118528814' EA\040name=''"
   *        annotation="TaggedValues xml.name='EXTERNAL-FAULT' xml.namePlural='EXTERNAL-FAULTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='false' xml.roleWrapperElement='true' xml.typeElement='true' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<MalfunctionPrototype> getExternalFault();

  /**
   * Returns the value of the '<em><b>External Failure</b></em>' containment reference list.
   * The list contents are of type {@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The external failures visible at the borders of the architectural element.
   * <!-- end-model-doc -->
   * @return the value of the '<em>External Failure</em>' containment reference list.
   * @see safe10.classmodel.errormodel.errormodeltype.ErrormodeltypePackage#getErrorModelType_ExternalFailure()
   * @model containment="true"
   *        annotation="MetaData guid='{9E78873D-A948-4d3e-A237-6789E709F76E}' id='481892100' EA\040name=''"
   *        annotation="TaggedValues xml.name='EXTERNAL-FAILURE' xml.namePlural='EXTERNAL-FAILURES' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='false' xml.roleWrapperElement='true' xml.typeElement='true' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<MalfunctionPrototype> getExternalFailure();

} // ErrorModelType
