/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.errormodel.malfunction;

import safe10.classmodel.commonstructure.toplevel.Identifiable;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Prototype</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A malfunction is a failure or unintended behavior of the item or element of the item that has the potential to propogate. The MalfunctionPrototype metaclass represents an error that may occur internally in an ErrorModel or be propagated to it, or a failure that is propagated out of an Error Model. The MalfunctionPrototype may represent different errors depending on its type (enumeration of generic description).
 * 
 * Semantics:
 * An malfunction prototype refers to a condition that deviates from expectations based on requirements specifications, design documents, user documents, standards, etc., or from someone's perceptions or experiences (ISO26262). The set of available faults or failures represented by the MalfunctionPrototype is defined by its type, typically an enumeration type like {omission, commission}. It is an abstract class further specialized with metaclasses for different types of fault/failure.
 * 
 * Extension:
 * (UML::Part)
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype#getGenericDescription <em>Generic Description</em>}</li>
 *   <li>{@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype#getMalfunction <em>Malfunction</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.errormodel.malfunction.MalfunctionPackage#getMalfunctionPrototype()
 * @model abstract="true"
 *        annotation="MetaData guid='{1796FECA-7118-40fa-9C81-F5D7E75453F4}' id='-1171674075' EA\040name='MalfunctionPrototype'"
 *        annotation="Stereotype Stereotype='atpPrototype'"
 *        annotation="TaggedValues xml.name='MALFUNCTION-PROTOTYPE' xml.namePlural='MALFUNCTION-PROTOTYPES' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface MalfunctionPrototype extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Generic Description</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * A description of the MalfunctionPrototype
   * <!-- end-model-doc -->
   * @return the value of the '<em>Generic Description</em>' attribute.
   * @see #isSetGenericDescription()
   * @see #unsetGenericDescription()
   * @see #setGenericDescription(String)
   * @see safe10.classmodel.errormodel.malfunction.MalfunctionPackage#getMalfunctionPrototype_GenericDescription()
   * @model default="" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.String" required="true"
   *        annotation="MetaData guid='{0CCFC6E3-3526-42f5-B71F-FA428A050C32}' id='977043586' EA\040name='genericDescription'"
   *        annotation="TaggedValues xml.name='GENERIC-DESCRIPTION' xml.namePlural='GENERIC-DESCRIPTIONS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  String getGenericDescription();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype#getGenericDescription <em>Generic Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Generic Description</em>' attribute.
   * @see #isSetGenericDescription()
   * @see #GenericDescription()
   * @see #getGenericDescription()
   * @generated
   */
  void setGenericDescription(String value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype#getGenericDescription <em>Generic Description</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetGenericDescription()
   * @see #getGenericDescription()
   * @see #setGenericDescription(String)
   * @generated
   */
  void unsetGenericDescription();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype#getGenericDescription <em>Generic Description</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Generic Description</em>' attribute is set.
   * @see #GenericDescription()
   * @see #getGenericDescription()
   * @see #setGenericDescription(String)
   * @generated
   */
  boolean isSetGenericDescription();

  /**
   * Returns the value of the '<em><b>Malfunction</b></em>' reference.
   * It is bidirectional and its opposite is '{@link safe10.classmodel.errormodel.malfunction.MalfunctionType#getIsOfType <em>Is Of Type</em>}'.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * The type of the malfunction prototype. It describes how the malfunction prototype becomes visible.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Malfunction</em>' reference.
   * @see #setMalfunction(MalfunctionType)
   * @see safe10.classmodel.errormodel.malfunction.MalfunctionPackage#getMalfunctionPrototype_Malfunction()
   * @see safe10.classmodel.errormodel.malfunction.MalfunctionType#getIsOfType
   * @model opposite="isOfType" required="true"
   *        annotation="MetaData guid='{4E0C592C-2C31-4787-A223-EEA5EEBF5A9B}' id='1218767231' EA\040name=''"
   *        annotation="TaggedValues xml.name='MALFUNCTION-REF' xml.namePlural='MALFUNCTION-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  MalfunctionType getMalfunction();

  /**
   * Sets the value of the '{@link safe10.classmodel.errormodel.malfunction.MalfunctionPrototype#getMalfunction <em>Malfunction</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Malfunction</em>' reference.
   * @see #getMalfunction()
   * @generated
   */
  void setMalfunction(MalfunctionType value);

} // MalfunctionPrototype
