/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hardware.failure;

import safe10.classmodel.commonstructure.toplevel.Referrable;

import safe10.classmodel.hardware.failurepart.HWComponentQuantifiedFMFromPart;

import safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Fault</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class HWFault represent the characterization of a HWComponent Fault defined by tags as Safe Fault, SinglePointFault or MultiplePointFault of a specific FailureMode in a context of an Hardware Architecture.
 * 
 * HardwareFault  can only exist for HardwareComponentPrototype when HWComponent are used given by the HWComponentPrototypeScope.
 * 
 * The related malfunction (link to violation of a SafetyGoals) is already linked with the FailureMode of the HardwareComponent via the HWSafetyGoalRelated meta class.
 * 
 * The different values are:
 * SafeFault: no violation of safety goal
 * ResidualOrSinglePointFault: direct violation of the SafetyGoal (1st order fault)
 * MultiplePointFault : violation of the SafetyGoal in combination with an independent failure of another component (minimum 2nd order)
 * 
 * Multiple-point fault for n&gt;2 are considered as safe faults unless shown to be relevant in the technical safety concept (see ISO Part 5 7.4.3.2 Note 1).
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hardware.failure.HWFault#getHwFaultType <em>Hw Fault Type</em>}</li>
 *   <li>{@link safe10.classmodel.hardware.failure.HWFault#getLambdaFailureModeValue <em>Lambda Failure Mode Value</em>}</li>
 *   <li>{@link safe10.classmodel.hardware.failure.HWFault#getHwFailureMode <em>Hw Failure Mode</em>}</li>
 *   <li>{@link safe10.classmodel.hardware.failure.HWFault#getHwFailureModeSingleContribution <em>Hw Failure Mode Single Contribution</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hardware.failure.FailurePackage#getHWFault()
 * @model annotation="MetaData guid='{36272151-D9B6-4c56-9EDE-442D02B473CE}' id='-784997424' EA\040name='HWFault'"
 *        annotation="TaggedValues xml.name='HW-FAULT' xml.namePlural='HW-FAULTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface HWFault extends Referrable
{
  /**
   * Returns the value of the '<em><b>Hw Fault Type</b></em>' attribute.
   * The default value is <code>"SAFEFAULT"</code>.
   * The literals are from the enumeration {@link safe10.classmodel.hardware.failure.HWPointFaultEnum}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Characterization of the Failure Mode for a single point related malfunction (linked to violation of a Safety Goal).
   * singlePoint Hw Fault Type can be either SPF or Residual
   * 
   * Possible Types are:
   * 
   * <ul>
   * 	<li>SafeFault (no violation of Safety Goal)</li>
   * 	<li>ResidualOrSinglePointFault (direct violation of Safety Goal (either covered by Safety Mechanism or not)</li>
   * 	<li>Multiple-Point-Fault (violation of Safety Goal in combination with another independent fault)</li>
   * </ul>
   * <!-- end-model-doc -->
   * @return the value of the '<em>Hw Fault Type</em>' attribute.
   * @see safe10.classmodel.hardware.failure.HWPointFaultEnum
   * @see #isSetHwFaultType()
   * @see #unsetHwFaultType()
   * @see #setHwFaultType(HWPointFaultEnum)
   * @see safe10.classmodel.hardware.failure.FailurePackage#getHWFault_HwFaultType()
   * @model default="SAFEFAULT" unsettable="true" required="true"
   *        annotation="MetaData guid='{C4C8E94B-25DE-4300-806D-EDFC2A8FF6D8}' id='354806673' EA\040name='hwFaultType'"
   *        annotation="TaggedValues xml.name='HW-FAULT-TYPE' xml.namePlural='HW-FAULT-TYPES' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  HWPointFaultEnum getHwFaultType();

  /**
   * Sets the value of the '{@link safe10.classmodel.hardware.failure.HWFault#getHwFaultType <em>Hw Fault Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Fault Type</em>' attribute.
   * @see safe10.classmodel.hardware.failure.HWPointFaultEnum
   * @see #isSetHwFaultType()
   * @see #HwFaultType()
   * @see #getHwFaultType()
   * @generated
   */
  void setHwFaultType(HWPointFaultEnum value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hardware.failure.HWFault#getHwFaultType <em>Hw Fault Type</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetHwFaultType()
   * @see #getHwFaultType()
   * @see #setHwFaultType(HWPointFaultEnum)
   * @generated
   */
  void unsetHwFaultType();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hardware.failure.HWFault#getHwFaultType <em>Hw Fault Type</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Hw Fault Type</em>' attribute is set.
   * @see #HwFaultType()
   * @see #getHwFaultType()
   * @see #setHwFaultType(HWPointFaultEnum)
   * @generated
   */
  boolean isSetHwFaultType();

  /**
   * Returns the value of the '<em><b>Lambda Failure Mode Value</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lambda Failure Mode Value</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lambda Failure Mode Value</em>' reference.
   * @see #setLambdaFailureModeValue(HWComponentQuantifiedFMFromPart)
   * @see safe10.classmodel.hardware.failure.FailurePackage#getHWFault_LambdaFailureModeValue()
   * @model annotation="MetaData guid='{E82580F3-517B-4936-BC3A-D2D18E78F33D}' id='-2037698283' EA\040name=''"
   *        annotation="TaggedValues xml.name='LAMBDA-FAILURE-MODE-VALUE-REF' xml.namePlural='LAMBDA-FAILURE-MODE-VALUE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  HWComponentQuantifiedFMFromPart getLambdaFailureModeValue();

  /**
   * Sets the value of the '{@link safe10.classmodel.hardware.failure.HWFault#getLambdaFailureModeValue <em>Lambda Failure Mode Value</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Lambda Failure Mode Value</em>' reference.
   * @see #getLambdaFailureModeValue()
   * @generated
   */
  void setLambdaFailureModeValue(HWComponentQuantifiedFMFromPart value);

  /**
   * Returns the value of the '<em><b>Hw Failure Mode</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Failure Mode</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Failure Mode</em>' reference.
   * @see #setHwFailureMode(HWFailureMode)
   * @see safe10.classmodel.hardware.failure.FailurePackage#getHWFault_HwFailureMode()
   * @model required="true"
   *        annotation="MetaData guid='{D78C03A5-5EE4-463c-AE4C-D44B5F808386}' id='1443787530' EA\040name=''"
   *        annotation="TaggedValues xml.name='HW-FAILURE-MODE-REF' xml.namePlural='HW-FAILURE-MODE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  HWFailureMode getHwFailureMode();

  /**
   * Sets the value of the '{@link safe10.classmodel.hardware.failure.HWFault#getHwFailureMode <em>Hw Failure Mode</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Failure Mode</em>' reference.
   * @see #getHwFailureMode()
   * @generated
   */
  void setHwFailureMode(HWFailureMode value);

  /**
   * Returns the value of the '<em><b>Hw Failure Mode Single Contribution</b></em>' reference.
   * It is bidirectional and its opposite is '{@link safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution#getNameWasNotSet_7 <em>Name Was Not Set 7</em>}'.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hw Failure Mode Single Contribution</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hw Failure Mode Single Contribution</em>' reference.
   * @see #setHwFailureModeSingleContribution(HWFMSingleContribution)
   * @see safe10.classmodel.hardware.failure.FailurePackage#getHWFault_HwFailureModeSingleContribution()
   * @see safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution#getNameWasNotSet_7
   * @model opposite="NameWasNotSet_7"
   *        annotation="TaggedValues xml.name='HW-FAILURE-MODE-SINGLE-CONTRIBUTION-REF' xml.namePlural='HW-FAILURE-MODE-SINGLE-CONTRIBUTION-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  HWFMSingleContribution getHwFailureModeSingleContribution();

  /**
   * Sets the value of the '{@link safe10.classmodel.hardware.failure.HWFault#getHwFailureModeSingleContribution <em>Hw Failure Mode Single Contribution</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hw Failure Mode Single Contribution</em>' reference.
   * @see #getHwFailureModeSingleContribution()
   * @generated
   */
  void setHwFailureModeSingleContribution(HWFMSingleContribution value);

} // HWFault
