/**
 */
package safe10.classmodel.hardware.failure;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import org.eclipse.emf.common.util.Enumerator;

/**
 * <!-- begin-user-doc -->
 * A representation of the literals of the enumeration '<em><b>HW Point Fault Enum</b></em>',
 * and utility methods for working with them.
 * <!-- end-user-doc -->
 * <!-- begin-model-doc -->
 * This enumeration includes the possible characterizations for the attribute hwFaultType in Class HWFault.
 * 
 * For simplification and clarification only SafeFault, SinglePointFault and DualPointFault and othersPointFault are derived from the ISO Part 5 7.4.3.2. 
 * 
 * SinglePointFault represents a first order fault, while DualPointFault represents a second order fault, and OthersPointFault order greater then two. For the hardware fault description, an cut set order of two is adequate. Therefore, an limited order of two (see ISO Part 5 7.4.3.2) can be defined. This means, that multiplePointFault represents an second order fault (dualPointFault).
 * 
 * The precise characterization of a HWFault (e.g. Multiple-Point-Latent) can be derived from the value of the attribute hwFaultType and a possible existence of a SafetyMechanism.
 * <!-- end-model-doc -->
 * @see safe10.classmodel.hardware.failure.FailurePackage#getHWPointFaultEnum()
 * @model annotation="MetaData guid='{04DB7C21-1DE2-436f-8EFC-0CDF2058521C}' id='2139558478' EA\040name='HWPointFaultEnum'"
 *        annotation="Stereotype Stereotype='enumeration'"
 *        annotation="TaggedValues xml.name='HW-POINT-FAULT-ENUM' xml.namePlural='HW-POINT-FAULT-ENUMS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public enum HWPointFaultEnum implements Enumerator
{
  /**
   * The '<em><b>Safe Fault</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #SAFE_FAULT_VALUE
   * @generated
   * @ordered
   */
  SAFE_FAULT(0, "safeFault", "SAFEFAULT"),

  /**
   * The '<em><b>Single Point Fault</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #SINGLE_POINT_FAULT_VALUE
   * @generated
   * @ordered
   */
  SINGLE_POINT_FAULT(1, "singlePointFault", "SINGLEPOINTFAULT"),

  /**
   * The '<em><b>Dual Point Fault</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #DUAL_POINT_FAULT_VALUE
   * @generated
   * @ordered
   */
  DUAL_POINT_FAULT(2, "dualPointFault", "DUALPOINTFAULT"),

  /**
   * The '<em><b>Others Point Fault</b></em>' literal object.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #OTHERS_POINT_FAULT_VALUE
   * @generated
   * @ordered
   */
  OTHERS_POINT_FAULT(3, "othersPointFault", "OTHERSPOINTFAULT");

  /**
   * The '<em><b>Safe Fault</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>Safe Fault</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #SAFE_FAULT
   * @model name="safeFault" literal="SAFEFAULT"
   *        annotation="TaggedValues xml.name='SAFE-FAULT' xml.namePlural='SAFE-FAULTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int SAFE_FAULT_VALUE = 0;

  /**
   * The '<em><b>Single Point Fault</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>Single Point Fault</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #SINGLE_POINT_FAULT
   * @model name="singlePointFault" literal="SINGLEPOINTFAULT"
   *        annotation="TaggedValues xml.name='SINGLE-POINT-FAULT' xml.namePlural='SINGLE-POINT-FAULTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int SINGLE_POINT_FAULT_VALUE = 1;

  /**
   * The '<em><b>Dual Point Fault</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>Dual Point Fault</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #DUAL_POINT_FAULT
   * @model name="dualPointFault" literal="DUALPOINTFAULT"
   *        annotation="TaggedValues xml.name='DUAL-POINT-FAULT' xml.namePlural='DUAL-POINT-FAULTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int DUAL_POINT_FAULT_VALUE = 2;

  /**
   * The '<em><b>Others Point Fault</b></em>' literal value.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of '<em><b>Others Point Fault</b></em>' literal object isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @see #OTHERS_POINT_FAULT
   * @model name="othersPointFault" literal="OTHERSPOINTFAULT"
   *        annotation="TaggedValues xml.name='OTHERS-POINT-FAULT' xml.namePlural='OTHERS-POINT-FAULTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   * @ordered
   */
  public static final int OTHERS_POINT_FAULT_VALUE = 3;

  /**
   * An array of all the '<em><b>HW Point Fault Enum</b></em>' enumerators.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private static final HWPointFaultEnum[] VALUES_ARRAY =
    new HWPointFaultEnum[]
    {
      SAFE_FAULT,
      SINGLE_POINT_FAULT,
      DUAL_POINT_FAULT,
      OTHERS_POINT_FAULT,
    };

  /**
   * A public read-only list of all the '<em><b>HW Point Fault Enum</b></em>' enumerators.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public static final List<HWPointFaultEnum> VALUES = Collections.unmodifiableList(Arrays.asList(VALUES_ARRAY));

  /**
   * Returns the '<em><b>HW Point Fault Enum</b></em>' literal with the specified literal value.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public static HWPointFaultEnum get(String literal)
  {
    for (int i = 0; i < VALUES_ARRAY.length; ++i)
    {
      HWPointFaultEnum result = VALUES_ARRAY[i];
      if (result.toString().equals(literal))
      {
        return result;
      }
    }
    return null;
  }

  /**
   * Returns the '<em><b>HW Point Fault Enum</b></em>' literal with the specified name.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public static HWPointFaultEnum getByName(String name)
  {
    for (int i = 0; i < VALUES_ARRAY.length; ++i)
    {
      HWPointFaultEnum result = VALUES_ARRAY[i];
      if (result.getName().equals(name))
      {
        return result;
      }
    }
    return null;
  }

  /**
   * Returns the '<em><b>HW Point Fault Enum</b></em>' literal with the specified integer value.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public static HWPointFaultEnum get(int value)
  {
    switch (value)
    {
      case SAFE_FAULT_VALUE: return SAFE_FAULT;
      case SINGLE_POINT_FAULT_VALUE: return SINGLE_POINT_FAULT;
      case DUAL_POINT_FAULT_VALUE: return DUAL_POINT_FAULT;
      case OTHERS_POINT_FAULT_VALUE: return OTHERS_POINT_FAULT;
    }
    return null;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private final int value;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private final String name;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private final String literal;

  /**
   * Only this class can construct instances.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private HWPointFaultEnum(int value, String name, String literal)
  {
    this.value = value;
    this.name = name;
    this.literal = literal;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public int getValue()
  {
    return value;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public String getName()
  {
    return name;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public String getLiteral()
  {
    return literal;
  }

  /**
   * Returns the literal value of the enumerator, which is its string representation.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  @Override
  public String toString()
  {
    return literal;
  }
  
} //HWPointFaultEnum
