/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hardware.failureformula;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.commonstructure.formulaexpression.AtpFormulaExpressionString;

import safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>HW Latent Fault Metric Formula</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * This class describes the latent fault metric (in %) as ratio of impact of latent faults for a top level malfunction (link to violation of a SafetyGoal) .
 * 
 * Latent metric  = 100% - total (multiple-point faults latent failure rate) /( total (safety-related HWComponent failure rate) - total (single-point faults failure rate + residual faults failure rate))
 * 
 * The formula expression shall be for each SafetyGoal:
 * Value( MultipleLatentFaultMetric) = { 1 - [  Sum (lambdaMultipleFaultLatent(FMSingleContribution) / [ Sum(LambdaSafetyComponent) - Sum ( lambdaSinglePointFault(FMSingleContribution) + lambdaResidualFault(FMSingleContribution)  ]   ]  } * 100
 * 
 * Value(MutiplePointFaultMteric) is applied on estimatedValue from electronic design level for final calculation and verification of the final latent fault metric. The selection between calculated and estimated value is a tool feature that allow first a calculation for estimation based on allocation field of failure rate and distribution. Only safety-related HWComponent are considered.
 * 
 * 
 * Sum(LambdaSafetyComponent) is only counted once for a HWElement (identical safetyComponentClassName).
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hardware.failureformula.HWLatentFaultMetricFormula#getLambdaValue <em>Lambda Value</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWLatentFaultMetricFormula()
 * @model annotation="MetaData guid='{47D63485-5FAC-49cb-A086-43B6F1347CE5}' id='-2036330063' EA\040name='HWLatentFaultMetricFormula'"
 *        annotation="TaggedValues xml.name='HW-LATENT-FAULT-METRIC-FORMULA' xml.namePlural='HW-LATENT-FAULT-METRIC-FORMULAS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface HWLatentFaultMetricFormula extends AtpFormulaExpressionString
{
  /**
   * Returns the value of the '<em><b>Lambda Value</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hardware.hwquantitativemeasure.HWFMSingleContribution}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Lambda Value</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Lambda Value</em>' reference list.
   * @see safe10.classmodel.hardware.failureformula.FailureformulaPackage#getHWLatentFaultMetricFormula_LambdaValue()
   * @model annotation="MetaData guid='{980D6453-0CCA-44f8-9DE3-937ED31B539F}' id='-1525602541' EA\040name=''"
   *        annotation="TaggedValues xml.name='LAMBDA-VALUE-REF' xml.namePlural='LAMBDA-VALUE-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<HWFMSingleContribution> getLambdaValue();

} // HWLatentFaultMetricFormula
