/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hazards;

import safe10.classmodel.commonstructure.toplevel.Identifiable;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Actor</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * The Actor class is an abstract class which provides the structure that is needed for the contributions of different actors to the operational situation and the hazard. 
 * 
 * <i><u>Note:</u></i>
 * The risk assessment of hazardous events focuses on the harm to each person potentially at risk  including the driver or the passengers of the vehicle causing the hazardous event, and other persons potentially at risk such as cyclists, pedestrians or occupants of other vehicles. 
 * <i><u>
 * </u></i><i><u>Reference: </u></i>
 * ISO26262-3-7.4.3.2
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hazards.Actor#getInformal <em>Informal</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.Actor#getFormal <em>Formal</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.Actor#getOperationalActor <em>Operational Actor</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.Actor#getOperationalCondition <em>Operational Condition</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hazards.HazardsPackage#getActor()
 * @model annotation="MetaData guid='{6BD046FA-A800-46db-83FA-138E3CF484CC}' id='-1412318172' EA\040name='Actor'"
 *        annotation="TaggedValues xml.name='ACTOR' xml.namePlural='ACTORS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface Actor extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Informal</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Provides the possibility to capture the informal description of the contribution of a particular actor
   * <!-- end-model-doc -->
   * @return the value of the '<em>Informal</em>' attribute.
   * @see #isSetInformal()
   * @see #unsetInformal()
   * @see #setInformal(String)
   * @see safe10.classmodel.hazards.HazardsPackage#getActor_Informal()
   * @model default="" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.String"
   *        annotation="MetaData guid='{D1D90C66-E6C7-491b-9630-959E5EEC02B3}' id='1128861426' EA\040name='informal'"
   *        annotation="TaggedValues xml.name='INFORMAL' xml.namePlural='INFORMALS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  String getInformal();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.Actor#getInformal <em>Informal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Informal</em>' attribute.
   * @see #isSetInformal()
   * @see #Informal()
   * @see #getInformal()
   * @generated
   */
  void setInformal(String value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.Actor#getInformal <em>Informal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetInformal()
   * @see #getInformal()
   * @see #setInformal(String)
   * @generated
   */
  void unsetInformal();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.Actor#getInformal <em>Informal</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Informal</em>' attribute is set.
   * @see #Informal()
   * @see #getInformal()
   * @see #setInformal(String)
   * @generated
   */
  boolean isSetInformal();

  /**
   * Returns the value of the '<em><b>Formal</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Provides the possibility to capture the formal description of the contribution of a particular actor
   * <!-- end-model-doc -->
   * @return the value of the '<em>Formal</em>' attribute.
   * @see #isSetFormal()
   * @see #unsetFormal()
   * @see #setFormal(String)
   * @see safe10.classmodel.hazards.HazardsPackage#getActor_Formal()
   * @model default="" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.String" required="true"
   *        annotation="MetaData guid='{D1DB2CFF-10E0-467c-8944-1389B7422F03}' id='-135894443' EA\040name='formal'"
   *        annotation="TaggedValues xml.name='FORMAL' xml.namePlural='FORMALS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  String getFormal();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.Actor#getFormal <em>Formal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Formal</em>' attribute.
   * @see #isSetFormal()
   * @see #Formal()
   * @see #getFormal()
   * @generated
   */
  void setFormal(String value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.Actor#getFormal <em>Formal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetFormal()
   * @see #getFormal()
   * @see #setFormal(String)
   * @generated
   */
  void unsetFormal();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.Actor#getFormal <em>Formal</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Formal</em>' attribute is set.
   * @see #Formal()
   * @see #getFormal()
   * @see #setFormal(String)
   * @generated
   */
  boolean isSetFormal();

  /**
   * Returns the value of the '<em><b>Operational Actor</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Operational Actor</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Operational Actor</em>' reference.
   * @see #setOperationalActor(OperationalActor)
   * @see safe10.classmodel.hazards.HazardsPackage#getActor_OperationalActor()
   * @model required="true"
   *        annotation="MetaData guid='{9B30BD7B-09BC-48af-80E8-8628351A40B2}' id='1760327342' EA\040name=''"
   *        annotation="TaggedValues xml.name='OPERATIONAL-ACTOR-REF' xml.namePlural='OPERATIONAL-ACTOR-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  OperationalActor getOperationalActor();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.Actor#getOperationalActor <em>Operational Actor</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Operational Actor</em>' reference.
   * @see #getOperationalActor()
   * @generated
   */
  void setOperationalActor(OperationalActor value);

  /**
   * Returns the value of the '<em><b>Operational Condition</b></em>' containment reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Operational Condition</em>' containment reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Operational Condition</em>' containment reference.
   * @see #setOperationalCondition(OperationalCondition)
   * @see safe10.classmodel.hazards.HazardsPackage#getActor_OperationalCondition()
   * @model containment="true"
   *        annotation="MetaData guid='{06802F1C-B7CA-470d-89A0-ABB1D7995922}' id='1356748868' EA\040name=''"
   *        annotation="TaggedValues xml.name='OPERATIONAL-CONDITION' xml.namePlural='OPERATIONAL-CONDITIONS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='true' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  OperationalCondition getOperationalCondition();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.Actor#getOperationalCondition <em>Operational Condition</em>}' containment reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Operational Condition</em>' containment reference.
   * @see #getOperationalCondition()
   * @generated
   */
  void setOperationalCondition(OperationalCondition value);

} // Actor
