/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hazards;

import safe10.classmodel.commonstructure.toplevel.Identifiable;

import safe10.classmodel.errormodel.malfunction.MalfunctionPrototype;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Hazard</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * A hazard describes a potential source of harm. Important is that it is formulated in terms of behavior that can be observed on vehicle level.
 * 
 * Hazards shall be defined in terms of the conditions or behavior that can be observed at the vehicle level. 
 * 
 * The hazards shall be determined systematically by using adequate techniques, such as brainstorming, checklists, quality history, FMEA and field studies.
 * 
 * <i><u>Reference:</u></i>
 * ISO 26262-3-7.4.2.2.2
 * ISO 26262-3-7.4.2.2.1
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hazards.Hazard#getFormal <em>Formal</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.Hazard#getInformal <em>Informal</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.Hazard#getMalfunction <em>Malfunction</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hazards.HazardsPackage#getHazard()
 * @model annotation="MetaData guid='{FBE4CEFB-5060-484b-8AF1-EAA98AEE2514}' id='1125210707' EA\040name='Hazard'"
 *        annotation="TaggedValues xml.name='HAZARD' xml.namePlural='HAZARDS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface Hazard extends Identifiable
{
  /**
   * Returns the value of the '<em><b>Formal</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Provides the possibility to capture the formal description of the hazard.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Formal</em>' attribute.
   * @see #isSetFormal()
   * @see #unsetFormal()
   * @see #setFormal(String)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazard_Formal()
   * @model default="" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.String" required="true"
   *        annotation="MetaData guid='{3EBE641F-F519-4b36-A1CC-6262F0955155}' id='-1762430312' EA\040name='formal'"
   *        annotation="TaggedValues xml.name='FORMAL' xml.namePlural='FORMALS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  String getFormal();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.Hazard#getFormal <em>Formal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Formal</em>' attribute.
   * @see #isSetFormal()
   * @see #Formal()
   * @see #getFormal()
   * @generated
   */
  void setFormal(String value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.Hazard#getFormal <em>Formal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetFormal()
   * @see #getFormal()
   * @see #setFormal(String)
   * @generated
   */
  void unsetFormal();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.Hazard#getFormal <em>Formal</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Formal</em>' attribute is set.
   * @see #Formal()
   * @see #getFormal()
   * @see #setFormal(String)
   * @generated
   */
  boolean isSetFormal();

  /**
   * Returns the value of the '<em><b>Informal</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Provides the possibility to capture the informal description of the hazard.
   * <!-- end-model-doc -->
   * @return the value of the '<em>Informal</em>' attribute.
   * @see #isSetInformal()
   * @see #unsetInformal()
   * @see #setInformal(String)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazard_Informal()
   * @model default="" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.String" required="true"
   *        annotation="MetaData guid='{3FE97368-C875-4dfa-B2EA-0B3F56003C91}' id='-272649031' EA\040name='informal'"
   *        annotation="TaggedValues xml.name='INFORMAL' xml.namePlural='INFORMALS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  String getInformal();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.Hazard#getInformal <em>Informal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Informal</em>' attribute.
   * @see #isSetInformal()
   * @see #Informal()
   * @see #getInformal()
   * @generated
   */
  void setInformal(String value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.Hazard#getInformal <em>Informal</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetInformal()
   * @see #getInformal()
   * @see #setInformal(String)
   * @generated
   */
  void unsetInformal();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.Hazard#getInformal <em>Informal</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Informal</em>' attribute is set.
   * @see #Informal()
   * @see #getInformal()
   * @see #setInformal(String)
   * @generated
   */
  boolean isSetInformal();

  /**
   * Returns the value of the '<em><b>Malfunction</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Malfunction</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Malfunction</em>' reference.
   * @see #setMalfunction(MalfunctionPrototype)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazard_Malfunction()
   * @model required="true"
   *        annotation="MetaData guid='{9972297D-33EF-49eb-A9B4-343579BB74C9}' id='-2080297029' EA\040name=''"
   *        annotation="TaggedValues xml.name='MALFUNCTION-REF' xml.namePlural='MALFUNCTION-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  MalfunctionPrototype getMalfunction();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.Hazard#getMalfunction <em>Malfunction</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Malfunction</em>' reference.
   * @see #getMalfunction()
   * @generated
   */
  void setMalfunction(MalfunctionPrototype value);

} // Hazard
