/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.hazards;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.commonstructure.datatypes.ASILEnum;

import safe10.classmodel.commonstructure.toplevel.Identifiable;

import safe10.classmodel.requirements.FunctionalSafetyRequirement;
import safe10.classmodel.requirements.TraceableSpecification;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Hazardous Event</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * The hazardous event describes a relevant outcome of combinations of a hazard and an operational situation. 
 * 
 * An ASIL shall be determined for each hazardous event using the parameters "severity", "probability of exposure" and "controllability" in accordance with Table 4. 
 * 
 * <i><u>Semantic:</u></i>
 * The ASIL shall be calculated automatically by using the information given in ISO26262-3-Table.4
 * 
 * <i><u>Reference:</u></i>
 * ISO 26262-3-7.4.2.2.3
 * ISO 26262-3-7.4.4.1
 * ISO 26262-3-Table.4
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getConsequences <em>Consequences</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getHazardClassification <em>Hazard Classification</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getExposure <em>Exposure</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getSeverity <em>Severity</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getControllability <em>Controllability</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getSafetyGoal <em>Safety Goal</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getEnvironment <em>Environment</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getOperationalSituation <em>Operational Situation</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getTraffic <em>Traffic</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getControllability2 <em>Controllability2</em>}</li>
 *   <li>{@link safe10.classmodel.hazards.HazardousEvent#getHazard <em>Hazard</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent()
 * @model annotation="MetaData guid='{40DDB7C0-40D7-4c0f-8468-6E63172A63D1}' id='1703341761' EA\040name='HazardousEvent'"
 *        annotation="TaggedValues xml.name='HAZARDOUS-EVENT' xml.namePlural='HAZARDOUS-EVENTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface HazardousEvent extends Identifiable, TraceableSpecification
{
  /**
   * Returns the value of the '<em><b>Consequences</b></em>' attribute.
   * The default value is <code>""</code>.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Provides the possibility to capture the consequences of a hazardous event.
   * 
   * <i><u>Reference:</u></i> 
   * ISO 26262-3-7.4.2.2.4
   * (The consequences of hazardous events shall be identified. )
   * <!-- end-model-doc -->
   * @return the value of the '<em>Consequences</em>' attribute.
   * @see #isSetConsequences()
   * @see #unsetConsequences()
   * @see #setConsequences(String)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_Consequences()
   * @model default="" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.String"
   *        annotation="MetaData guid='{A18A751D-D8C3-4d64-B147-B3E32689104E}' id='-1099342354' EA\040name='consequences'"
   *        annotation="TaggedValues xml.name='CONSEQUENCES' xml.namePlural='CONSEQUENCESS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  String getConsequences();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getConsequences <em>Consequences</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Consequences</em>' attribute.
   * @see #isSetConsequences()
   * @see #Consequences()
   * @see #getConsequences()
   * @generated
   */
  void setConsequences(String value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getConsequences <em>Consequences</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetConsequences()
   * @see #getConsequences()
   * @see #setConsequences(String)
   * @generated
   */
  void unsetConsequences();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getConsequences <em>Consequences</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Consequences</em>' attribute is set.
   * @see #Consequences()
   * @see #getConsequences()
   * @see #setConsequences(String)
   * @generated
   */
  boolean isSetConsequences();

  /**
   * Returns the value of the '<em><b>Hazard Classification</b></em>' attribute.
   * The default value is <code>"ASIL_A"</code>.
   * The literals are from the enumeration {@link safe10.classmodel.commonstructure.datatypes.ASILEnum}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * Based on Table 4 defined in ISO26262-3 the ASIL shall be allocated to the hazardous event based on the classification of the attributes
   * <ul>
   * 	<li>Controllability</li>
   * 	<li>Severity</li>
   * 	<li>Exposure</li>
   * </ul>
   * <!-- end-model-doc -->
   * @return the value of the '<em>Hazard Classification</em>' attribute.
   * @see safe10.classmodel.commonstructure.datatypes.ASILEnum
   * @see #isSetHazardClassification()
   * @see #unsetHazardClassification()
   * @see #setHazardClassification(ASILEnum)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_HazardClassification()
   * @model default="ASIL_A" unsettable="true" required="true"
   *        annotation="MetaData guid='{0BDD06EE-0CE0-4436-907F-05680B1A7F28}' id='498683154' EA\040name='hazardClassification'"
   *        annotation="TaggedValues xml.name='HAZARD-CLASSIFICATION' xml.namePlural='HAZARD-CLASSIFICATIONS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  ASILEnum getHazardClassification();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getHazardClassification <em>Hazard Classification</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hazard Classification</em>' attribute.
   * @see safe10.classmodel.commonstructure.datatypes.ASILEnum
   * @see #isSetHazardClassification()
   * @see #HazardClassification()
   * @see #getHazardClassification()
   * @generated
   */
  void setHazardClassification(ASILEnum value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getHazardClassification <em>Hazard Classification</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetHazardClassification()
   * @see #getHazardClassification()
   * @see #setHazardClassification(ASILEnum)
   * @generated
   */
  void unsetHazardClassification();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getHazardClassification <em>Hazard Classification</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Hazard Classification</em>' attribute is set.
   * @see #HazardClassification()
   * @see #getHazardClassification()
   * @see #setHazardClassification(ASILEnum)
   * @generated
   */
  boolean isSetHazardClassification();

  /**
   * Returns the value of the '<em><b>Exposure</b></em>' attribute.
   * The default value is <code>"E1"</code>.
   * The literals are from the enumeration {@link safe10.classmodel.hazards.ExposureClassKind}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * <b>Exposure</b> is defined as the state of being in an <b>operational situation </b> that can be <b>hazardous</b> if coincident with the <b>failure mode </b>under analysis 
   * <i><u>
   * </u></i><i><u>Reference:</u></i>
   * ISO 26262-1-1.37
   * ISO 26262-1-1.83
   * ISO 26262-1-1.57
   * ISO 26262-1-1.40
   * <!-- end-model-doc -->
   * @return the value of the '<em>Exposure</em>' attribute.
   * @see safe10.classmodel.hazards.ExposureClassKind
   * @see #isSetExposure()
   * @see #unsetExposure()
   * @see #setExposure(ExposureClassKind)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_Exposure()
   * @model default="E1" unsettable="true" required="true"
   *        annotation="MetaData guid='{DE320B56-F2CE-4e73-9451-4AF2ABFDBECF}' id='1920965469' EA\040name='exposure'"
   *        annotation="TaggedValues xml.name='EXPOSURE' xml.namePlural='EXPOSURES' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  ExposureClassKind getExposure();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getExposure <em>Exposure</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Exposure</em>' attribute.
   * @see safe10.classmodel.hazards.ExposureClassKind
   * @see #isSetExposure()
   * @see #Exposure()
   * @see #getExposure()
   * @generated
   */
  void setExposure(ExposureClassKind value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getExposure <em>Exposure</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetExposure()
   * @see #getExposure()
   * @see #setExposure(ExposureClassKind)
   * @generated
   */
  void unsetExposure();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getExposure <em>Exposure</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Exposure</em>' attribute is set.
   * @see #Exposure()
   * @see #getExposure()
   * @see #setExposure(ExposureClassKind)
   * @generated
   */
  boolean isSetExposure();

  /**
   * Returns the value of the '<em><b>Severity</b></em>' attribute.
   * The default value is <code>"S0"</code>.
   * The literals are from the enumeration {@link safe10.classmodel.hazards.SeverityClassKind}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * <b>Severity </b>is defined as the<b> </b>estimation of the extent of <b>harm</b> to one or more individuals that can occur in a potentially <b>hazardous</b> situation 
   * 
   * <i><u>Reference:</u></i>
   * ISO 26262-1-1.120
   * ISO 26262-1-1.56
   * ISO 26262-1-1.57
   * <!-- end-model-doc -->
   * @return the value of the '<em>Severity</em>' attribute.
   * @see safe10.classmodel.hazards.SeverityClassKind
   * @see #isSetSeverity()
   * @see #unsetSeverity()
   * @see #setSeverity(SeverityClassKind)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_Severity()
   * @model default="S0" unsettable="true" required="true"
   *        annotation="MetaData guid='{7A0BF924-CCB0-4450-97CC-4C0540A81C57}' id='-1941709478' EA\040name='severity'"
   *        annotation="TaggedValues xml.name='SEVERITY' xml.namePlural='SEVERITYS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  SeverityClassKind getSeverity();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getSeverity <em>Severity</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Severity</em>' attribute.
   * @see safe10.classmodel.hazards.SeverityClassKind
   * @see #isSetSeverity()
   * @see #Severity()
   * @see #getSeverity()
   * @generated
   */
  void setSeverity(SeverityClassKind value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getSeverity <em>Severity</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetSeverity()
   * @see #getSeverity()
   * @see #setSeverity(SeverityClassKind)
   * @generated
   */
  void unsetSeverity();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getSeverity <em>Severity</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Severity</em>' attribute is set.
   * @see #Severity()
   * @see #getSeverity()
   * @see #setSeverity(SeverityClassKind)
   * @generated
   */
  boolean isSetSeverity();

  /**
   * Returns the value of the '<em><b>Controllability</b></em>' attribute.
   * The default value is <code>"C0"</code>.
   * The literals are from the enumeration {@link safe10.classmodel.hazards.ControllabilityClassKind}.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * <!-- begin-model-doc -->
   * <b>Controllability </b>is defined as the ability to avoid a specified <b>harm</b> or damage through the timely reactions of the persons involved, possibly with support from <b>external measures</b>
   * 
   * <i><u>NOTE:</u></i> 
   * <ol>
   * 	<li>Persons involved can include the driver, passengers or persons in the vicinity of the vehicle's exterior. </li>
   * 	<li>The parameter C <b>in hazard analysis and risk assessment </b>represents the potential for controllability. </li>
   * </ol>
   * 
   * <i><u>Reference:</u></i>
   * ISO 26262-1.19
   * ISO 26262-1.56
   * ISO 26262-1.38
   * ISO 26262-1.58
   * <!-- end-model-doc -->
   * @return the value of the '<em>Controllability</em>' attribute.
   * @see safe10.classmodel.hazards.ControllabilityClassKind
   * @see #isSetControllability()
   * @see #unsetControllability()
   * @see #setControllability(ControllabilityClassKind)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_Controllability()
   * @model default="C0" unsettable="true" required="true"
   *        annotation="MetaData guid='{6BA0DDE8-FEA4-43ac-8BF4-47CA20A88B63}' id='-182794368' EA\040name='controllability'"
   *        annotation="TaggedValues xml.name='CONTROLLABILITY' xml.namePlural='CONTROLLABILITYS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  ControllabilityClassKind getControllability();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getControllability <em>Controllability</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Controllability</em>' attribute.
   * @see safe10.classmodel.hazards.ControllabilityClassKind
   * @see #isSetControllability()
   * @see #Controllability()
   * @see #getControllability()
   * @generated
   */
  void setControllability(ControllabilityClassKind value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getControllability <em>Controllability</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetControllability()
   * @see #getControllability()
   * @see #setControllability(ControllabilityClassKind)
   * @generated
   */
  void unsetControllability();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getControllability <em>Controllability</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Controllability</em>' attribute is set.
   * @see #Controllability()
   * @see #getControllability()
   * @see #setControllability(ControllabilityClassKind)
   * @generated
   */
  boolean isSetControllability();

  /**
   * Returns the value of the '<em><b>Safety Goal</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.requirements.FunctionalSafetyRequirement}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Safety Goal</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Safety Goal</em>' reference list.
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_SafetyGoal()
   * @model required="true"
   *        annotation="MetaData guid='{19F6FFF6-1314-4b4f-9474-6A17DD953EC3}' id='-1858036243' EA\040name=''"
   *        annotation="TaggedValues xml.name='SAFETY-GOAL-REF' xml.namePlural='SAFETY-GOAL-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<FunctionalSafetyRequirement> getSafetyGoal();

  /**
   * Returns the value of the '<em><b>Environment</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hazards.OperationalSituation}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Environment</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Environment</em>' reference list.
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_Environment()
   * @model annotation="MetaData guid='{4ABF1186-C556-491c-ADE3-9351441875F5}' id='-801870112' EA\040name=''"
   *        annotation="TaggedValues xml.name='ENVIRONMENT-REF' xml.namePlural='ENVIRONMENT-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<OperationalSituation> getEnvironment();

  /**
   * Returns the value of the '<em><b>Operational Situation</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Operational Situation</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Operational Situation</em>' reference.
   * @see #setOperationalSituation(OperationalSituation)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_OperationalSituation()
   * @model required="true"
   *        annotation="MetaData guid='{18564C90-A2B3-49ad-9114-EAF3C8998266}' id='134883410' EA\040name=''"
   *        annotation="TaggedValues xml.name='OPERATIONAL-SITUATION-REF' xml.namePlural='OPERATIONAL-SITUATION-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  OperationalSituation getOperationalSituation();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getOperationalSituation <em>Operational Situation</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Operational Situation</em>' reference.
   * @see #getOperationalSituation()
   * @generated
   */
  void setOperationalSituation(OperationalSituation value);

  /**
   * Returns the value of the '<em><b>Traffic</b></em>' reference list.
   * The list contents are of type {@link safe10.classmodel.hazards.OperationalSituation}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Traffic</em>' reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Traffic</em>' reference list.
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_Traffic()
   * @model annotation="MetaData guid='{20A161DF-EA79-4113-B3A9-CA1DA39AD727}' id='215268705' EA\040name=''"
   *        annotation="TaggedValues xml.name='TRAFFIC-REF' xml.namePlural='TRAFFIC-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='true' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<OperationalSituation> getTraffic();

  /**
   * Returns the value of the '<em><b>Controllability2</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Controllability2</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Controllability2</em>' reference.
   * @see #setControllability2(ControllabilityReference)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_Controllability2()
   * @model required="true"
   *        annotation="MetaData guid='{F7017812-2B9A-42c3-B4E6-4DF6AB64898C}' id='1077115467' EA\040name=''"
   *        annotation="TaggedValues xml.name='CONTROLLABILITY-2-REF' xml.namePlural='CONTROLLABILITY-2-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  ControllabilityReference getControllability2();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getControllability2 <em>Controllability2</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Controllability2</em>' reference.
   * @see #getControllability2()
   * @generated
   */
  void setControllability2(ControllabilityReference value);

  /**
   * Returns the value of the '<em><b>Hazard</b></em>' reference.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Hazard</em>' reference isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Hazard</em>' reference.
   * @see #setHazard(Hazard)
   * @see safe10.classmodel.hazards.HazardsPackage#getHazardousEvent_Hazard()
   * @model required="true"
   *        annotation="MetaData guid='{5655A256-DC17-4b59-9D52-0A323F6A5011}' id='1740214805' EA\040name=''"
   *        annotation="TaggedValues xml.name='HAZARD-REF' xml.namePlural='HAZARD-REFS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  Hazard getHazard();

  /**
   * Sets the value of the '{@link safe10.classmodel.hazards.HazardousEvent#getHazard <em>Hazard</em>}' reference.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Hazard</em>' reference.
   * @see #getHazard()
   * @generated
   */
  void setHazard(Hazard value);

} // HazardousEvent
