/**
 * <copyright>
 * </copyright>
 *
 * $Id$
 */
package safe10.classmodel.requirements;

import org.eclipse.emf.common.util.EList;

import safe10.classmodel.software.configuration.CodeGenerationConfiguration;

/**
 * <!-- begin-user-doc -->
 * A representation of the model object '<em><b>Technical Safety Requirement</b></em>'.
 * <!-- end-user-doc -->
 *
 * <!-- begin-model-doc -->
 * TechnicalSafetyRequirements are used to specify the implementation of the associated FunctionComponent . They are derived by the allocated FunctionalSafetyRequirements.
 * TechnicalSafetyRequirements include the specification of safety-related failure mitigation.  
 * 
 * The  technical safety requirements specification refines the functional safety concept, considering both the functional concept and the preliminary architectural assumptions
 * 
 * The technical safety requirements are allocated to hardware and software, and, if applicable, on other technologies 
 * 
 * <b><i><u>Reference:</u></i></b> 
 * <i>ISO26262-1-1.133</i>
 * <i>ISO26262-4- 6.4.9</i>
 * <!-- end-model-doc -->
 *
 * <p>
 * The following features are supported:
 * <ul>
 *   <li>{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getRequirementKind <em>Requirement Kind</em>}</li>
 *   <li>{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getRedundancy <em>Redundancy</em>}</li>
 *   <li>{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getCodegenconfiguration <em>Codegenconfiguration</em>}</li>
 * </ul>
 * </p>
 *
 * @see safe10.classmodel.requirements.RequirementsPackage#getTechnicalSafetyRequirement()
 * @model annotation="MetaData guid='{FFA0F059-B072-4ba1-97D6-E22382C284F9}' id='732814633' EA\040name='TechnicalSafetyRequirement'"
 *        annotation="TaggedValues xml.name='TECHNICAL-SAFETY-REQUIREMENT' xml.namePlural='TECHNICAL-SAFETY-REQUIREMENTS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1'"
 *        annotation="EAAdapter metaModelType='SAFE'"
 * @generated
 */
public interface TechnicalSafetyRequirement extends HasFaultTolerantTimeInterval, AbstractSafetyRequirement, HasEmergencyOperationTimeInterval, HasAsilDecomposed
{
  /**
   * Returns the value of the '<em><b>Requirement Kind</b></em>' attribute.
   * The default value is <code>"QUANTITATIVE"</code>.
   * The literals are from the enumeration {@link safe10.classmodel.requirements.RequirementKind}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Requirement Kind</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Requirement Kind</em>' attribute.
   * @see safe10.classmodel.requirements.RequirementKind
   * @see #isSetRequirementKind()
   * @see #unsetRequirementKind()
   * @see #setRequirementKind(RequirementKind)
   * @see safe10.classmodel.requirements.RequirementsPackage#getTechnicalSafetyRequirement_RequirementKind()
   * @model default="QUANTITATIVE" unsettable="true" required="true"
   *        annotation="MetaData guid='{1DF7FF71-049C-4905-9505-A85B21016BAA}' id='236750518' EA\040name='requirementKind'"
   *        annotation="TaggedValues xml.name='REQUIREMENT-KIND' xml.namePlural='REQUIREMENT-KINDS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  RequirementKind getRequirementKind();

  /**
   * Sets the value of the '{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getRequirementKind <em>Requirement Kind</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Requirement Kind</em>' attribute.
   * @see safe10.classmodel.requirements.RequirementKind
   * @see #isSetRequirementKind()
   * @see #RequirementKind()
   * @see #getRequirementKind()
   * @generated
   */
  void setRequirementKind(RequirementKind value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getRequirementKind <em>Requirement Kind</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetRequirementKind()
   * @see #getRequirementKind()
   * @see #setRequirementKind(RequirementKind)
   * @generated
   */
  void unsetRequirementKind();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getRequirementKind <em>Requirement Kind</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Requirement Kind</em>' attribute is set.
   * @see #RequirementKind()
   * @see #getRequirementKind()
   * @see #setRequirementKind(RequirementKind)
   * @generated
   */
  boolean isSetRequirementKind();

  /**
   * Returns the value of the '<em><b>Redundancy</b></em>' attribute.
   * The default value is <code>"false"</code>.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Redundancy</em>' attribute isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Redundancy</em>' attribute.
   * @see #isSetRedundancy()
   * @see #unsetRedundancy()
   * @see #setRedundancy(Boolean)
   * @see safe10.classmodel.requirements.RequirementsPackage#getTechnicalSafetyRequirement_Redundancy()
   * @model default="false" unsettable="true" dataType="safe10.classmodel.commonstructure.datatypes.Boolean" required="true"
   *        annotation="MetaData guid='{ACB8A1E9-7B10-4a89-A004-2D517173ABD4}' id='2132806223' EA\040name='redundancy'"
   *        annotation="TaggedValues xml.name='REDUNDANCY' xml.namePlural='REDUNDANCYS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='true' xml.roleWrapperElement='false' xml.typeElement='false' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  Boolean getRedundancy();

  /**
   * Sets the value of the '{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getRedundancy <em>Redundancy</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param value the new value of the '<em>Redundancy</em>' attribute.
   * @see #isSetRedundancy()
   * @see #Redundancy()
   * @see #getRedundancy()
   * @generated
   */
  void setRedundancy(Boolean value);

  /**
   * Unsets the value of the '{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getRedundancy <em>Redundancy</em>}' attribute.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #isSetRedundancy()
   * @see #getRedundancy()
   * @see #setRedundancy(Boolean)
   * @generated
   */
  void unsetRedundancy();

  /**
   * Returns whether the value of the '{@link safe10.classmodel.requirements.TechnicalSafetyRequirement#getRedundancy <em>Redundancy</em>}' attribute is set.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return whether the value of the '<em>Redundancy</em>' attribute is set.
   * @see #Redundancy()
   * @see #getRedundancy()
   * @see #setRedundancy(Boolean)
   * @generated
   */
  boolean isSetRedundancy();

  /**
   * Returns the value of the '<em><b>Codegenconfiguration</b></em>' containment reference list.
   * The list contents are of type {@link safe10.classmodel.software.configuration.CodeGenerationConfiguration}.
   * <!-- begin-user-doc -->
   * <p>
   * If the meaning of the '<em>Codegenconfiguration</em>' containment reference list isn't clear,
   * there really should be more of a description here...
   * </p>
   * <!-- end-user-doc -->
   * @return the value of the '<em>Codegenconfiguration</em>' containment reference list.
   * @see safe10.classmodel.requirements.RequirementsPackage#getTechnicalSafetyRequirement_Codegenconfiguration()
   * @model containment="true"
   *        annotation="MetaData guid='{9ECA3CE4-BEC2-4e1b-BC76-8D2AA52D6FE3}' id='1585110012' EA\040name=''"
   *        annotation="TaggedValues xml.name='CODEGENCONFIGURATION' xml.namePlural='CODEGENCONFIGURATIONS' xml.nsPrefix='EA' xml.nsUri='http://safe-project.eu/1.0.1' xml.roleElement='false' xml.roleWrapperElement='true' xml.typeElement='true' xml.typeWrapperElement='false'"
   *        annotation="EAAdapter metaModelType='SAFE'"
   * @generated
   */
  EList<CodeGenerationConfiguration> getCodegenconfiguration();

} // TechnicalSafetyRequirement
